==> yak_runner-0.2.1%2B3.tar.gz: test/mixin/result/on_result_async_test.dart <==
import 'dart:async';

import 'package:mockito/mockito.dart';
import 'package:test/test.dart';
import 'package:yak_runner/yak_runner.dart';
import '../../mocks/all.dart';

void main() {
  final _data = 1;
  final _res = '$_data';
  final _errorHandler = MockErrorHandler();
  when(_errorHandler(any, any)).thenAnswer(null);

  group('`onResultAsync` MIXIN', () {
    final _firstDelegate = MockDelegate<int>();
    final _secondDelegate = MockUnaryDelegate<Future<String>, FutureOr<int>>();

    final _firstRunner = YakRunner<int>(_firstDelegate, _errorHandler);
    final _secondRunner =
        YakRunnerArgAsync<String, int>(_secondDelegate, _errorHandler);

    test('WHEN `Delegate<S>` fails THEN  `onResult() return Failure<T>',
        () async {
      reset(_errorHandler);
      reset(_firstDelegate);
      reset(_secondDelegate);

      when(_firstDelegate()).thenThrow(Exception());
      when(_secondDelegate(_data)).thenAnswer((_) async => _res);

      final _result =
          await _firstRunner().onFutureResult<String>(_secondRunner);

      expect(
        _result,
        isNotNull,
        reason: '`_result` must not be null',
      );
      expect(
        _result,
        isNot(Success),
        reason: '`_result` should not be `Success`',
      );
      expect(
        _result is Failure<int>,
        false,
        reason: '`_result`should not be `Failure<S>`',
      );
      expect(
        _result,
        isA<Failure<String>>(),
        reason: '`_result` should be `Failure<T>`',
      );

      verify(_firstDelegate()).called(1);
      verify(_errorHandler(any, any)).called(1);
      verifyZeroInteractions(_secondDelegate);
    });

    test(
        'WHEN `ArgDelegate<Future<T>,FutureOr<S>>` fail '
        'THEN  `onResult() return Failure<T>', () async {
      reset(_errorHandler);
      reset(_firstDelegate);
      reset(_secondDelegate);

      when(_firstDelegate()).thenAnswer((_) => _data);
      when(_secondDelegate(_data)).thenThrow(Exception());

      final _result =
          await _firstRunner().onFutureResult<String>(_secondRunner);

      expect(
        _result,
        isNotNull,
        reason: '`_result` must not be null',
      );
      expect(
        _result,
        isNot(Success),
        reason: '`_result` should not be `Success`',
      );
      expect(
        _result is Failure<int>,
        false,
        reason: '`_result`should not be `Failure<S>`',
      );
      expect(
        _result,
        isA<Failure<String>>(),
        reason: '`_result` should be `Failure<T>`',
      );

      verify(_firstDelegate()).called(1);
      verify(_secondDelegate(_data)).called(1);
      verify(_errorHandler(any, any)).called(1);
    });

    test(
        'WHEN `ArgDelegate<Future<T>,FutureOr<S>>` does not fail '
        'THEN  `onResult() return Success<T>', () async {
      reset(_errorHandler);
      reset(_firstDelegate);
      reset(_secondDelegate);

      when(_firstDelegate()).thenAnswer((_) => _data);
      when(_secondDelegate(_data)).thenAnswer((_) async => _res);

      final _result =
          await _firstRunner().onFutureResult<String>(_secondRunner);

      expect(
        _result,
        isNotNull,
        reason: '`_result` must not be null',
      );
      expect(
        _result,
        isA<Success>(),
        reason: '`_result` should be `Success`',
      );

      expect(
        _result,
        isNot(Failure),
        reason: '`_result` should not be `Failure`',
      );

      verify(_firstDelegate()).called(1);
      verify(_secondDelegate(_data)).called(1);
      verifyZeroInteractions(_errorHandler);
    });
  });
}

==> yak_runner-0.2.2%2B3.tar.gz: test/mixin/result/on_result_async_test.dart <==
import 'dart:async';

import 'package:mockito/mockito.dart';
import 'package:test/test.dart';
import 'package:yak_runner/yak_runner.dart';
import '../../mocks/all.dart';

void main() {
  final _data = 1;
  final _res = '$_data';
  final _exceptionHandler = MockExceptionHandler();
  when(_exceptionHandler(any, any)).thenAnswer(null);

  group('`onResultAsync` MIXIN', () {
    final _firstDelegate = MockDelegate<int>();
    final _secondDelegate = MockUnaryDelegate<Future<String>, FutureOr<int>>();

    final _firstRunner = YakRunner<int>(
      _firstDelegate,
      handleException: _exceptionHandler,
    );
    final _secondRunner = YakRunnerArgAsync<String, int>(
      _secondDelegate,
      handleException: _exceptionHandler,
    );

    test('WHEN `Delegate<S>` fails THEN  `onResult() return Failure<T>',
        () async {
      reset(_exceptionHandler);
      reset(_firstDelegate);
      reset(_secondDelegate);

      when(_firstDelegate()).thenThrow(Exception());
      when(_secondDelegate(_data)).thenAnswer((_) async => _res);

      final _result =
          await _firstRunner().onFutureResult<String>(_secondRunner);

      expect(
        _result,
        isNotNull,
        reason: '`_result` must not be null',
      );
      expect(
        _result,
        isNot(Success),
        reason: '`_result` should not be `Success`',
      );
      expect(
        _result is Failure<int>,
        false,
        reason: '`_result`should not be `Failure<S>`',
      );
      expect(
        _result,
        isA<Failure<String>>(),
        reason: '`_result` should be `Failure<T>`',
      );

      verify(_firstDelegate()).called(1);
      verify(_exceptionHandler(any, any)).called(1);
      verifyZeroInteractions(_secondDelegate);
    });

    test(
        'WHEN `ArgDelegate<Future<T>,FutureOr<S>>` fail '
        'THEN  `onResult() return Failure<T>', () async {
      reset(_exceptionHandler);
      reset(_firstDelegate);
      reset(_secondDelegate);

      when(_firstDelegate()).thenAnswer((_) => _data);
      when(_secondDelegate(_data)).thenThrow(Exception());

      final _result =
          await _firstRunner().onFutureResult<String>(_secondRunner);

      expect(
        _result,
        isNotNull,
        reason: '`_result` must not be null',
      );
      expect(
        _result,
        isNot(Success),
        reason: '`_result` should not be `Success`',
      );
      expect(
        _result is Failure<int>,
        false,
        reason: '`_result`should not be `Failure<S>`',
      );
      expect(
        _result,
        isA<Failure<String>>(),
        reason: '`_result` should be `Failure<T>`',
      );

      verify(_firstDelegate()).called(1);
      verify(_secondDelegate(_data)).called(1);
      verify(_exceptionHandler(any, any)).called(1);
    });

    test(
        'WHEN `ArgDelegate<Future<T>,FutureOr<S>>` does not fail '
        'THEN  `onResult() return Success<T>', () async {
      reset(_exceptionHandler);
      reset(_firstDelegate);
      reset(_secondDelegate);

      when(_firstDelegate()).thenAnswer((_) => _data);
      when(_secondDelegate(_data)).thenAnswer((_) async => _res);

      final _result =
          await _firstRunner().onFutureResult<String>(_secondRunner);

      expect(
        _result,
        isNotNull,
        reason: '`_result` must not be null',
      );
      expect(
        _result,
        isA<Success>(),
        reason: '`_result` should be `Success`',
      );

      expect(
        _result,
        isNot(Failure),
        reason: '`_result` should not be `Failure`',
      );

      verify(_firstDelegate()).called(1);
      verify(_secondDelegate(_data)).called(1);
      verifyZeroInteractions(_exceptionHandler);
    });
  });
}
